@@ -1,5 +1,5 @@
 #[cfg(feature = "luau")]
-use full_moon::ast::types::{IndexedTypeInfo, TypeAssertion, TypeInfo, TypeSpecifier};
+use full_moon::ast::types::{IndexedTypeInfo, TypeAssertion, TypeField, TypeInfo, TypeSpecifier};
 use full_moon::ast::{
     punctuated::Punctuated, span::ContainedSpan, BinOp, Call, Expression, FunctionArgs,
     FunctionBody, FunctionCall, FunctionName, Index, MethodCall, Parameter, Prefix, Suffix,
@@ -631,6 +631,11 @@ define_update_trailing_trivia!(TypeInfo, |this, trailing| {
             right: Box::new(right.update_trailing_trivia(trailing)),
         },
 
+        TypeInfo::Variadic { ellipse, type_info } => TypeInfo::Variadic {
+            ellipse: ellipse.to_owned(),
+            type_info: Box::new(type_info.update_trailing_trivia(trailing)),
+        },
+
         other => panic!("unknown node {:?}", other),
     }
 });
@@ -661,6 +666,12 @@ define_update_trailing_trivia!(TypeAssertion, |this, trailing| {
         .with_cast_to(this.cast_to().update_trailing_trivia(trailing))
 });
 
+#[cfg(feature = "luau")]
+define_update_trailing_trivia!(TypeField, |this, trailing| {
+    this.to_owned()
+        .with_value(this.value().update_trailing_trivia(trailing))
+});
+
 #[cfg(feature = "luau")]
 define_update_trailing_trivia!(TypeSpecifier, |this, trailing| {
     this.to_owned()
