@@ -3,7 +3,7 @@ use crate::formatters::trivia::{FormatTriviaType, UpdateTrailingTrivia};
 use full_moon::ast::span::ContainedSpan;
 #[cfg(feature = "luau")]
 use full_moon::ast::types::{IndexedTypeInfo, TypeDeclaration, TypeField, TypeInfo};
-use full_moon::ast::Block;
+use full_moon::ast::{Block, FunctionBody};
 use full_moon::{
     ast::{
         BinOp, Call, Expression, Field, FunctionArgs, Index, LastStmt, Prefix, Stmt, Suffix,
@@ -67,6 +67,20 @@ pub fn is_block_empty(block: &Block) -> bool {
     block.stmts().next().is_none() && block.last_stmt().is_none()
 }
 
+pub fn is_function_empty(function_body: &FunctionBody) -> bool {
+    is_block_empty(function_body.block())
+        && !function_body
+            .parameters_parentheses()
+            .tokens()
+            .1
+            .trailing_trivia()
+            .any(trivia_is_comment)
+        && !function_body
+            .end_token()
+            .leading_trivia()
+            .any(trivia_is_comment)
+}
+
 // TODO: Can we clean this up? A lot of this code is repeated in trivia_formatter
 fn function_args_trailing_trivia<'ast>(function_args: &FunctionArgs<'ast>) -> Vec<Token<'ast>> {
     match function_args {
